pub struct SigFlags {
pub signatures_exist: bool,
pub append_only: bool,
}Expand description
/SigFlags bit field.
Fields
signatures_exist: boolBit 0: at least one signature field exists in the document.
append_only: boolBit 1: incremental updates only — modifying the document outside of new signatures must be done via append.