Module lexer

Module lexer 

PDF tokenizer.

Structs

Lexer
PDF lexer operating on a byte slice with a cursor.

Enums

Token
PDF token types.

Constants

MAX_OBJECT_DEPTH
Maximum nesting depth for arrays and dictionaries within a single object.

Functions

parse_dict_body
Parse dictionary entries until >>, returning a PdfDict.
parse_dict_body_at_depth
parse_dict_body, entered at an explicit container nesting depth.
parse_object
Parse a PDF object from the lexer (recursive descent).
parse_object_at_depth
parse_object, entered at an explicit container nesting depth.
parse_object_from_token
Parse a PDF object given an already-consumed first token.
parse_object_from_token_at_depth
parse_object_from_token, entered at an explicit container nesting depth.