PDF tokenizer.
Structs
- Lexer
- PDF lexer operating on a byte slice with a cursor.
Enums
- Token
- PDF token types.
Constants
- MAX_
OBJECT_ DEPTH - Maximum nesting depth for arrays and dictionaries within a single object.
Functions
- parse_
dict_ body - Parse dictionary entries until
>>, returning a PdfDict. - parse_
dict_ body_ at_ depth parse_dict_body, entered at an explicit container nesting depth.- parse_
object - Parse a PDF object from the lexer (recursive descent).
- parse_
object_ at_ depth parse_object, entered at an explicit container nesting depth.- parse_
object_ from_ token - Parse a PDF object given an already-consumed first token.
- parse_
object_ from_ token_ at_ depth parse_object_from_token, entered at an explicit container nesting depth.